@@ -5,9 +5,6 @@ use Mouse::Util::TypeConstraints ();
 around initialize => sub {
     shift; # original method; not used
     my $self = shift;
-    if( @_ == 1 and Mouse::Util::TypeConstraints::HashRef($_[0]) ) {
-        return $_[0];
-    }
 
     my %args;
     my $rules = $self->rules;
